/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be
 useful, but WITHOUT ANY WARRANTY; without even the implied 
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 PURPOSE.  See the GNU General Public License for more details.
 
 */

package com.clustercontrol.snmptrap.bean;


/**
 * SNMPTRAP監視更新をmBeanに送信するトピックの定数クラス<BR>
 *
 * SNMPトラップ監視では、TOPIC_NAME_UPDATE というTopicを用います。
 *
 * @version 2.1.0
 * @since 2.1.0
 */
public class TopicConstant {
	/** SNMPTRAP監視更新用トピック */
	public static final String TOPIC_NAME_UPDATE = "topic/clustercontrolSnmpTrapUpdate";
}
